@@ -348,7 +348,7 @@ def hyphen(text):
   return hypen0,hypen1
 
 # entity words 
-def entity(text):
+"""def entity(text):
   doc = nlp(text)
   entity0 =[]
   entity1 = []
@@ -359,7 +359,36 @@ def entity(text):
       enttj = "".join(entt.split())
       entity1.append(enttj)
   #print(entity0,entity1)
-  return entity0,entity1
+  return entity0,entity1"""
+# entity words + some proper noun e.g. paradise 
+def entity(text):
+  doc = nlp(text)
+  entity0 =[]
+  entity1 = []
+  text1 = text
+  for ent in doc.ents:
+      #print(ent.text, ent.start_char, ent.end_char, ent.label_)
+      entt = ent.text
+      text1 = re.sub(r'\b' + entt + r'\b',"    ", text1)
+      entity0.append(entt)
+      enttj = "".join(entt.split())
+      entity1.append(enttj)
+  #print(entity0,entity1)
+  doc2 = nlp(text1)
+  propns0 = []
+  propns1 = []
+  
+  for token in doc2:
+        if token.pos_ =="PROPN":
+            propn = token.text
+            propns0.append(propn)
+            propnj = "".join(propn.split())
+            propns1.append(propnj)          
+            
+  return entity0 + propns0 ,entity1 +propns1
+
+
+
 
 #9 n't lemmatize(ntverb)
 # (ntwerb)change n't to not Apostrophe
