@@ -182,7 +182,7 @@ class unit2sent:
     avnWs = []
     avnPs =[]
     for edge in commu1_edges:
-      if c_noun in edge[1]:
+      if c_noun == edge[1]:
         avn = edge[0]
         if 'nnn' in avn:
           avnP ='NOUN'
